@@ -28,7 +28,7 @@
 
 G_BEGIN_DECLS
 
-#define MT_ICON_NAME  "gnome-dev-mouse-optical"
+#define MT_ICON_NAME  "input-mouse"
 
 #define MT_GCONF_HOME "/desktop/gnome/accessibility/mouse"
 #define OPT_THRESHOLD MT_GCONF_HOME "/threshold"
@@ -75,6 +75,8 @@ typedef enum {
     MT_MESSAGE_LOGOUT
 } MtMessageType;
 
+void mt_common_show_help   (GdkScreen     *screen,
+			    guint32        timestamp);
 gint mt_common_show_dialog (const gchar   *primary,
 			    const gchar   *secondary,
 			    MtMessageType  type);
